@@ -1,7 +1,7 @@
 from pypk.pypi_update import pypi_update
 from pypk.pypi_upload import pypi_upload
 import os
-from clear_console import clearConsole
+from pypk.clear_console import clearConsole
 
 def run():
     while True:
