@@ -1,6 +1,6 @@
 import os
 from pathlib import Path
-from clear_console import clearConsole
+from pypk.clear_console import clearConsole
 
 
 def pypi_upload():
